@@ -16,7 +16,7 @@ import morganBody from 'morgan-body';
 import helmet from 'helmet';
 import compression from 'compression';
 import cookieParser from 'cookie-parser';
-import inspect from '@stolostron/security-middleware';
+import inspect from '@open-cluster-management/security-middleware';
 import noCache from 'nocache';
 import authMiddleware from './lib/auth-middleware';
 import logger from './lib/logger';
@@ -84,11 +84,15 @@ const graphQLServer = express();
 graphQLServer.use(compression());
 
 // These headers are dealt with in icp-management-ingress
-graphQLServer.use('*', helmet({
-  frameguard: false,
-  noSniff: false,
-  xssFilter: false,
-}), noCache(), cookieParser());
+const callbacks = isProd
+  ? [helmet({
+    frameguard: false,
+    noSniff: false,
+    xssFilter: false,
+  })]
+  : [];
+callbacks.push(noCache(), cookieParser());
+graphQLServer.use('*', callbacks);
 
 graphQLServer.get('/livenessProbe', (req, res) => {
   res.send(`Testing livenessProbe --> ${new Date().toLocaleString()}`);
